Coverage for tests/test_file_utils.py: 100%

1 from image_utils import get_files

2 import pytest

3 from pathlib import Path

4

5 folder_path = Path('tests')

6

7

8@pytest.mark.parametrize("recursive", [True, False])

9@pytest.mark.parametrize("return_folders", [True, False])

10@pytest.mark.parametrize("allowed_extensions", [None, ['png'], ['png', 'jpg']])

11 def test_get_files(recursive, return_folders, allowed_extensions):

12 for file in get_files(folder_path, recursive, return_folders, allowed_extensions):

13 print(file)